"""
Class object for MediaTrackerConfig
Documentation:

Generated by generator/generator.py - 2023-05-09 14:40:06.285643
"""
from .base import MediaTrackerBaseClient


class MediaTrackerConfig(MediaTrackerBaseClient):
    @property
    def enableRegistration(self):
        return self.attributes.get("enableRegistration", True)

    @property
    def tmdbLang(self):
        return self.attributes.get("tmdbLang", "")

    @property
    def audibleLang(self):
        return self.attributes.get("audibleLang", "")

    @property
    def serverLang(self):
        return self.attributes.get("serverLang", "")

    @property
    def igdbClientId(self):
        return self.attributes.get("igdbClientId", "")

    @property
    def igdbClientSecret(self):
        return self.attributes.get("igdbClientSecret", "")

    @property
    def noUsers(self):
        return self.attributes.get("noUsers", False)

    @property
    def demo(self):
        return self.attributes.get("demo", False)

    @property
    def version(self):
        return self.attributes.get("version", "")
